"""

@Auther : Mason
@Date   : 
"""
import grpc
import time
from treelab.config import sleep_time, sleep_number
from functools import wraps


def cycle(event_name):
    """
    Query event GRPC error loop query
    :param event_name:
    :return:
    """
    def wrapper(func):
        @wraps(func)
        def inner_wrapper(*args, **kwargs):
            for i in range(sleep_number):
                value = ''
                try:
                    if event_name == 'workspace':
                        value = kwargs['workspace_id']
                        return func(args[0], workspace_id=value)
                    elif event_name == 'core':
                        value = args[1]
                        return func(args[0], core_id=value, workspace=args[2])
                    elif event_name == 'table':
                        value = args[1]
                        return func(args[0], table_id=value, core=args[2])
                    elif event_name == 'update_data':
                        table = kwargs['table'] if kwargs else args[0]
                        value = table.id
                        return func(table=table)
                    elif event_name == 'get_all_cores':
                        return func(args[0])
                    elif event_name == 'get_all_tables':
                        return func(args[0])
                    else:
                        raise ValueError('not event_name')
                except grpc.RpcError:
                    if event_name == 'update_data':
                        time.sleep(i)
                        continue
                    print('Missing ', event_name, ' ', value)
                    time.sleep(sleep_time + i)
                if i <= 9:
                    pass
                else:
                    raise ValueError('Missing ', event_name, ' ', value)

        return inner_wrapper

    return wrapper


def dormancy(event_name):
    """
    Put the update operation to sleep
    :param event_name:
    :return:
    """

    def wrapper(func):
        @wraps(func)
        def inner_wrapper(*args, **kwargs):
            time.sleep(sleep_time)
            if event_name == 'cell_update':
                return func(args[0], value=kwargs['value'])

        return inner_wrapper

    return wrapper



# server
workspace_id = 'wsp51aee96517063914'
# core 1
core_id_1 = 'cre51aeeb329c8d730d'
view_id_1 = 'viw51af07c50a0969e0'
table_id_1 = 'tbl51aeee11660d81c8'
column_id_1 = 'col51afae2e078653a5'
column_name_1 = 'col_name1'
view_name_1 = 'viewname'
row_id_1 = 'row51af93a17a8bfe75'
core_name_1 = 'test_pysdk'

# # local
# workspace_id = 'wspb595e72fbb8ef9bd'
# # core 1
# core_id_1 = 'creb595e72fd00a840d'
# view_id_1 = 'viwb595e731b801592d'
# table_id_1 = 'tblb595e7303809d5c3'
# column_id_1 = 'colb5957e93a08baf08'
# column_name_1 = 'col_name1'
# view_name_1 = 'viewname'
# row_id_1 = 'rowb5957e920a816926'
# core_name_1 = 'test_pysdk'

sleep_number = 10
sleep_time = 0.1
